@@ -64,19 +64,19 @@ namespace gnote {
     {
       std::string message;
 
-      // %1% is the number of note.
-      message = ngettext("Really delete this note?", "Really delete these %1% notes?", notes.size());
-
-      boost::format format(message);
-      // make sure an exception is not raised for the non-plural form
-      format.exceptions( boost::io::all_error_bits ^ 
-                         ( boost::io::too_many_args_bit | 
-                           boost::io::too_few_args_bit )  );
+      if(notes.size() == 1) {
+        // TRANSLATORS: %1% will be replaced by note title
+        message = str(boost::format("Really delete \"%1%\"?") % notes.front()->get_title());
+      }
+      else {
+        // TRANSLATORS: %1% is number of notes
+        message = str(boost::format(ngettext("Really delete %1% note?", "Really delete %1% notes?", notes.size())) % notes.size());
+      }
 
       utils::HIGMessageDialog dialog(parent, GTK_DIALOG_DESTROY_WITH_PARENT,
                                      Gtk::MESSAGE_QUESTION,
                                      Gtk::BUTTONS_NONE,
-                                     str(format % notes.size()),
+                                     message,
                                      _("If you delete a note it is permanently lost."));
 
       Gtk::Button *button;
@@ -800,10 +800,9 @@ namespace gnote {
     }
 
     if (!linking_notes.empty()) {
-      Preferences & preferences = Preferences::obj();
+      Glib::RefPtr<Gio::Settings> settings = Preferences::obj().get_schema_settings(Preferences::SCHEMA_GNOTE);
       const NoteRenameBehavior behavior
-        = static_cast<NoteRenameBehavior>(
-            preferences.get<int>(Preferences::NOTE_RENAME_BEHAVIOR));
+        = static_cast<NoteRenameBehavior>(settings->get_int(Preferences::NOTE_RENAME_BEHAVIOR));
 
       if (NOTE_RENAME_ALWAYS_SHOW_DIALOG == behavior) {
         NoteRenameDialog dlg(linking_notes, old_title, self);
@@ -813,8 +812,7 @@ namespace gnote {
         if (Gtk::RESPONSE_CANCEL != response
             && NOTE_RENAME_ALWAYS_SHOW_DIALOG
                  != selected_behavior) {
-          preferences.set<int>(Preferences::NOTE_RENAME_BEHAVIOR,
-                               selected_behavior);
+          settings->set_int(Preferences::NOTE_RENAME_BEHAVIOR, selected_behavior);
         }
 
         const NoteRenameDialog::MapPtr notes = dlg.get_notes();
@@ -1105,7 +1103,7 @@ namespace gnote {
 
   const Glib::RefPtr<NoteTagTable> & Note::get_tag_table()
   {
-    if (m_tag_table == NULL) {
+    if (!m_tag_table) {
       // NOTE: Sharing the same TagTable means
       // that formatting is duplicated between
       // buffers.
@@ -1175,7 +1173,8 @@ namespace gnote {
 
   bool Note::is_pinned() const
   {
-    std::string pinned_uris = Preferences::obj().get<std::string>(Preferences::MENU_PINNED_NOTES);
+    std::string pinned_uris = Preferences::obj()
+      .get_schema_settings(Preferences::SCHEMA_GNOTE)->get_string(Preferences::MENU_PINNED_NOTES);
     return (boost::find_first(pinned_uris, uri()));
   }
 
@@ -1183,8 +1182,8 @@ namespace gnote {
   void Note::set_pinned(bool pinned) const
   {
     std::string new_pinned;
-    // this is like a calle to is_pinned() but we want to reating the gconf value
-    std::string old_pinned = Preferences::obj().get<std::string>(Preferences::MENU_PINNED_NOTES);
+    Glib::RefPtr<Gio::Settings> settings = Preferences::obj().get_schema_settings(Preferences::SCHEMA_GNOTE);
+    std::string old_pinned = settings->get_string(Preferences::MENU_PINNED_NOTES);
     bool is_currently_pinned = (boost::find_first(old_pinned, uri()));
 
     if (pinned == is_currently_pinned)
@@ -1204,7 +1203,7 @@ namespace gnote {
         }
       }
     }
-    Preferences::obj().set<std::string>(Preferences::MENU_PINNED_NOTES, new_pinned);
+    settings->set_string(Preferences::MENU_PINNED_NOTES, new_pinned);
   }
 
   
