@@ -73,13 +73,19 @@ namespace gnote {
           "      </placeholder>"
           "    </menu>"
           "  </menubar>"
+          "  <popup name='MainWindowContextMenu' action='MainWindowContextMenuAction'>"
+          "    <menuitem name='OpenNote' action='OpenNoteAction' />"
+          "    <menuitem name='DeleteNote' action='DeleteNoteAction' />"
+          "    <placeholder name='MainWindowContextMenuPlaceholder'>"
+          "      <separator />"
+          "      <menuitem name='NewNote' action='NewNotebookNoteAction' />"
+          "    </placeholder>"
+          "  </popup>"
           "  <popup name='NotebooksTreeContextMenu' action='NotebooksTreeContextMenuAction'>"
           "    <menuitem name='NewNotebookNote' action='NewNotebookNoteAction' />"
-          "    <separator />"
           "    <menuitem name='OpenNotebookTemplateNote' action='OpenNotebookTemplateNoteAction' />"
           "    <menuitem name='DeleteNotebook' action='DeleteNotebookAction' />"
-          "  </popup>"
-          "  <popup name='NotebooksTreeNoRowContextMenu' action='NotebooksTreeNoRowContextMenuAction'>"
+          "    <separator />"
           "    <menuitem name='NewNotebook' action='NewNotebookAction' />"
           "  </popup>"
           "  <popup name='TrayIconMenu' action='TrayIconMenuAction'>"
