@@ -80,7 +80,7 @@ namespace gnote {
     find_item->signal_activate().connect(sigc::mem_fun(*this, &NoteWindow::find_button_clicked));
     find_item->add_accelerator ("activate",
                                 m_accel_group,
-                                GDK_F,
+                                GDK_KEY_F,
                                 Gdk::CONTROL_MASK,
                                 Gtk::ACCEL_VISIBLE);
     find_item->show ();
@@ -128,10 +128,14 @@ namespace gnote {
 
     // Don't set up Ctrl-W or Ctrl-N if Emacs is in use
     bool using_emacs = false;
-    std::string gtk_key_theme = 
-      Preferences::obj().get<std::string>("/desktop/gnome/interface/gtk_key_theme");
+    Glib::RefPtr<Gio::Settings> desktop_settings = Preferences::obj()
+      .get_or_load_schema_settings(Preferences::SCHEMA_DESKTOP_GNOME_INTERFACE);
+    if(desktop_settings) {
+      std::string gtk_key_theme = 
+        desktop_settings->get_string(Preferences::DESKTOP_GNOME_KEY_THEME);
     if (!gtk_key_theme.empty() && (gtk_key_theme == "Emacs"))
       using_emacs = true;
+    }
 
     // NOTE: Since some of our keybindings are only
     // available in the context menu, and the context menu
@@ -142,7 +146,7 @@ namespace gnote {
     // Close window (Ctrl-W)
     if (!using_emacs)
       m_global_keys->add_accelerator (sigc::mem_fun(*this, &NoteWindow::close_window_handler),
-                                      GDK_W,
+                                      GDK_KEY_W,
                                       Gdk::CONTROL_MASK,
                                       Gtk::ACCEL_VISIBLE);
 
@@ -151,29 +155,29 @@ namespace gnote {
 
     // Close all windows on current Desktop (Ctrl-Q)
     m_global_keys->add_accelerator (sigc::mem_fun(*this, &NoteWindow::close_all_windows_handler),
-                                   GDK_Q,
+                                   GDK_KEY_Q,
                                    Gdk::CONTROL_MASK,
                                    Gtk::ACCEL_VISIBLE);
 
     // Find Next (Ctrl-G)
     m_global_keys->add_accelerator (sigc::mem_fun(*this, &NoteWindow::find_next_activate),
-                                 GDK_G,
+                                 GDK_KEY_G,
                                  Gdk::CONTROL_MASK,
                                  Gtk::ACCEL_VISIBLE);
 
     // Find Previous (Ctrl-Shift-G)
     m_global_keys->add_accelerator (sigc::mem_fun(*this, &NoteWindow::find_previous_activate),
-                                 GDK_G, (Gdk::CONTROL_MASK | Gdk::SHIFT_MASK),
+                                 GDK_KEY_G, (Gdk::CONTROL_MASK | Gdk::SHIFT_MASK),
                                  Gtk::ACCEL_VISIBLE);
 
     // Open Help (F1)
     m_global_keys->add_accelerator (sigc::mem_fun(*this, &NoteWindow::open_help_activate),
-                                    GDK_F1, (Gdk::ModifierType)0, (Gtk::AccelFlags)0);
+                                    GDK_KEY_F1, (Gdk::ModifierType)0, (Gtk::AccelFlags)0);
 
     // Create a new note
     if (!using_emacs)
       m_global_keys->add_accelerator (sigc::mem_fun(*this, &NoteWindow::create_new_note),
-                                     GDK_N, Gdk::CONTROL_MASK,
+                                     GDK_KEY_N, Gdk::CONTROL_MASK,
                                      Gtk::ACCEL_VISIBLE);
 
     signal_key_press_event().connect(sigc::mem_fun(*this, &NoteWindow::on_key_pressed));
@@ -181,12 +185,12 @@ namespace gnote {
 
     // Increase Indent
     m_global_keys->add_accelerator (sigc::mem_fun(*this, &NoteWindow::change_depth_right_handler),
-                                   GDK_Right, Gdk::MOD1_MASK,
+                                   GDK_KEY_Right, Gdk::MOD1_MASK,
                                    Gtk::ACCEL_VISIBLE);
 
     // Decrease Indent
     m_global_keys->add_accelerator (sigc::mem_fun(*this, &NoteWindow::change_depth_left_handler),
-                                   GDK_Left, Gdk::MOD1_MASK,
+                                   GDK_KEY_Left, Gdk::MOD1_MASK,
                                    Gtk::ACCEL_VISIBLE);
     add(*box);
   }
@@ -200,7 +204,6 @@ namespace gnote {
     m_mark_set_timeout = NULL;
     // make sure editor is NULL. See bug 586084
     m_editor = NULL;
-    Preferences::obj().remove_notify(m_gconf_notify);
   }
 
 
@@ -225,11 +228,11 @@ namespace gnote {
 
   bool NoteWindow::on_key_pressed(GdkEventKey *ev)
   {
-    if(ev->keyval == GDK_Escape) {
-      if (m_find_bar && m_find_bar->is_visible()) {
+    if(ev->keyval == GDK_KEY_Escape) {
+      if (m_find_bar && m_find_bar->get_visible()) {
         m_find_bar->hide();
       }
-      else if (Preferences::obj().get<bool>(
+      else if (Preferences::obj().get_schema_settings(Preferences::SCHEMA_GNOTE)->get_boolean(
                  Preferences::ENABLE_CLOSE_NOTE_ON_ESCAPE)) {
         close_window_handler();
       }
@@ -317,7 +320,7 @@ namespace gnote {
                                           _("_Search All Notes"), true));
     search->set_image(*manage(new Gtk::Image (Gtk::Stock::FIND, Gtk::ICON_SIZE_MENU)));
     search->signal_activate().connect(sigc::mem_fun(*this, &NoteWindow::search_button_clicked));
-    search->add_accelerator ("activate", m_accel_group, GDK_F,
+    search->add_accelerator ("activate", m_accel_group, GDK_KEY_F,
                              (Gdk::CONTROL_MASK |  Gdk::SHIFT_MASK),
                              Gtk::ACCEL_VISIBLE);
     search->show();
@@ -326,7 +329,7 @@ namespace gnote {
     link->set_image(*manage(new Gtk::Image (Gtk::Stock::JUMP_TO, Gtk::ICON_SIZE_MENU)));
     link->set_sensitive(!m_note.get_buffer()->get_selection().empty());
     link->signal_activate().connect(sigc::mem_fun(*this, &NoteWindow::link_button_clicked));
-    link->add_accelerator("activate", m_accel_group, GDK_L,
+    link->add_accelerator("activate", m_accel_group, GDK_KEY_L,
                           Gdk::CONTROL_MASK, Gtk::ACCEL_VISIBLE);
     link->show();
       
@@ -358,7 +361,7 @@ namespace gnote {
     close_all->signal_activate().connect(
       sigc::mem_fun(*this, &NoteWindow::close_all_windows_handler));
     close_all->add_accelerator("activate", m_accel_group,
-                               GDK_Q, Gdk::CONTROL_MASK, Gtk::ACCEL_VISIBLE);
+                               GDK_KEY_Q, Gdk::CONTROL_MASK, Gtk::ACCEL_VISIBLE);
     close_all->show();
 
     Gtk::ImageMenuItem *close_window = manage(
@@ -367,7 +370,7 @@ namespace gnote {
     close_window->signal_activate().connect(
       sigc::mem_fun(*this, &NoteWindow::close_window_handler));
     close_window->add_accelerator("activate", m_accel_group,
-                                  GDK_W,
+                                  GDK_KEY_W,
                                   Gdk::CONTROL_MASK, Gtk::ACCEL_VISIBLE);
     close_window->show();
 
@@ -395,7 +398,7 @@ namespace gnote {
     search->signal_clicked().connect(sigc::mem_fun(*this, &NoteWindow::search_button_clicked));
     search->set_tooltip_text(_("Search your notes (Ctrl-Shift-F)"));
     search->add_accelerator("clicked", m_accel_group,
-                             GDK_F,
+                             GDK_KEY_F,
                              (Gdk::CONTROL_MASK | Gdk::SHIFT_MASK),
                              Gtk::ACCEL_VISIBLE);
     search->show_all();
@@ -411,7 +414,7 @@ namespace gnote {
       sigc::mem_fun(*this, &NoteWindow::link_button_clicked));
     m_link_button->set_tooltip_text(_("Link selected text to a new note (Ctrl-L)"));
     m_link_button->add_accelerator("clicked", m_accel_group,
-                                   GDK_L, Gdk::CONTROL_MASK,
+                                   GDK_KEY_L, Gdk::CONTROL_MASK,
                                    Gtk::ACCEL_VISIBLE);
     m_link_button->show_all();
     tb->insert(*m_link_button, -1);
@@ -500,7 +503,7 @@ namespace gnote {
     find->set_image(*manage(new Gtk::Image (Gtk::Stock::FIND, Gtk::ICON_SIZE_MENU)));
     find->signal_activate().connect(sigc::mem_fun(*this, &NoteWindow::find_button_clicked));
     find->add_accelerator("activate", m_accel_group,
-                          GDK_F, Gdk::CONTROL_MASK,
+                          GDK_KEY_F, Gdk::CONTROL_MASK,
                           Gtk::ACCEL_VISIBLE);
     find->show();
 
@@ -510,7 +513,7 @@ namespace gnote {
 
     find_next->signal_activate().connect(sigc::mem_fun(*this, &NoteWindow::find_next_activate));
     find_next->add_accelerator("activate", m_accel_group,
-                              GDK_G, Gdk::CONTROL_MASK,
+                              GDK_KEY_G, Gdk::CONTROL_MASK,
                               Gtk::ACCEL_VISIBLE);
     find_next->show();
 
@@ -520,7 +523,7 @@ namespace gnote {
 
     find_previous->signal_activate().connect(sigc::mem_fun(*this, &NoteWindow::find_previous_activate));
     find_previous->add_accelerator("activate", m_accel_group,
-                                  GDK_G, (Gdk::CONTROL_MASK | Gdk::SHIFT_MASK),
+                                  GDK_KEY_G, (Gdk::CONTROL_MASK | Gdk::SHIFT_MASK),
                                   Gtk::ACCEL_VISIBLE);
     find_previous->show();
 
@@ -622,6 +625,13 @@ namespace gnote {
     Glib::RefPtr<NoteBuffer>::cast_static(m_editor->get_buffer())->change_cursor_depth_directional(false);
   }
 
+  void NoteWindow::on_show()
+  {
+    utils::ForcedPresentWindow::on_show();
+    // Make sure the cursor position is visible
+    m_editor->scroll_to (m_editor->get_buffer()->get_insert());
+  }
+
   
   NoteFindBar::NoteFindBar(Note & note)
     : Gtk::HBox(false, 0)
@@ -776,7 +786,7 @@ namespace gnote {
     buffer->move_mark(buffer->get_selection_bound(), start);
 
     Gtk::TextView *editor = m_note.get_window()->editor();
-    editor->scroll_mark_onscreen(buffer->get_insert());
+    editor->scroll_to(buffer->get_insert());
   }
 
 
@@ -921,15 +931,15 @@ namespace gnote {
   {
     switch (ev->keyval)
     {
-    case GDK_Escape:
+    case GDK_KEY_Escape:
       hide();
       break;
-    case GDK_Shift_L:
-    case GDK_Shift_R:
+    case GDK_KEY_Shift_L:
+    case GDK_KEY_Shift_R:
       m_shift_key_pressed = true;
       return false;
       break;
-    case GDK_Return:
+    case GDK_KEY_Return:
       if (m_shift_key_pressed)
         m_prev_button.clicked();
       break;
@@ -945,8 +955,8 @@ namespace gnote {
   {
     switch (ev->keyval)
     {
-    case GDK_Shift_L:
-    case GDK_Shift_R:
+    case GDK_KEY_Shift_L:
+    case GDK_KEY_Shift_R:
       m_shift_key_pressed = false;
       break;
     }
@@ -1106,7 +1116,7 @@ namespace gnote {
 //      m_undo->set_accel_group(accel_group);
       m_undo->signal_activate().connect(sigc::mem_fun(*this, &NoteTextMenu::undo_clicked));
       m_undo->add_accelerator ("activate", accel_group,
-                               GDK_Z,
+                               GDK_KEY_Z,
                                Gdk::CONTROL_MASK,
                                Gtk::ACCEL_VISIBLE);
       m_undo->show();
@@ -1116,7 +1126,7 @@ namespace gnote {
 //      m_redo->set_accel_group(accel_group);
       m_redo->signal_activate().connect(sigc::mem_fun(*this, &NoteTextMenu::redo_clicked));
       m_redo->add_accelerator ("activate", accel_group,
-                               GDK_Z, (Gdk::CONTROL_MASK |
+                               GDK_KEY_Z, (Gdk::CONTROL_MASK |
                                        Gdk::SHIFT_MASK),
                                Gtk::ACCEL_VISIBLE);
       m_redo->show();
@@ -1135,7 +1145,7 @@ namespace gnote {
       m_bold.signal_activate()
         .connect(sigc::bind(sigc::mem_fun(*this, &NoteTextMenu::font_style_clicked), &m_bold));
       m_bold.add_accelerator ("activate", accel_group,
-                           GDK_B,
+                           GDK_KEY_B,
                            Gdk::CONTROL_MASK,
                            Gtk::ACCEL_VISIBLE);
 
@@ -1145,7 +1155,7 @@ namespace gnote {
         .connect(sigc::bind(sigc::mem_fun(*this, &NoteTextMenu::font_style_clicked), &m_italic));
       m_italic.add_accelerator ("activate",
                              accel_group,
-                             GDK_I,
+                             GDK_KEY_I,
                              Gdk::CONTROL_MASK,
                              Gtk::ACCEL_VISIBLE);
 
@@ -1155,7 +1165,7 @@ namespace gnote {
         .connect(sigc::bind(sigc::mem_fun(*this, &NoteTextMenu::font_style_clicked), &m_strikeout));
       m_strikeout.add_accelerator ("activate",
                                 accel_group,
-                                GDK_S,
+                                GDK_KEY_S,
                                 Gdk::CONTROL_MASK,
                                 Gtk::ACCEL_VISIBLE);
 
@@ -1165,7 +1175,7 @@ namespace gnote {
         .connect(sigc::bind(sigc::mem_fun(*this, &NoteTextMenu::font_style_clicked), &m_highlight));
       m_highlight.add_accelerator ("activate",
                                 accel_group,
-                                GDK_H,
+                                GDK_KEY_H,
                                 Gdk::CONTROL_MASK,
                                 Gtk::ACCEL_VISIBLE);
 
@@ -1198,7 +1208,7 @@ namespace gnote {
 
       m_increase_font.add_accelerator ("activate",
                                        accel_group,
-                                       GDK_plus,
+                                       GDK_KEY_plus,
                                        Gdk::CONTROL_MASK,
                                        Gtk::ACCEL_VISIBLE);
       m_increase_font.signal_activate()
@@ -1206,7 +1216,7 @@ namespace gnote {
 
       m_decrease_font.add_accelerator ("activate",
                                        accel_group,
-                                       GDK_minus,
+                                       GDK_KEY_minus,
                                        Gdk::CONTROL_MASK,
                                        Gtk::ACCEL_VISIBLE);
       m_decrease_font.signal_activate()
@@ -1219,7 +1229,7 @@ namespace gnote {
 
 //      m_increase_indent.set_accel_group(accel_group);
       m_increase_indent.add_accelerator ("activate", accel_group,
-                                       GDK_Right,
+                                       GDK_KEY_Right,
                                        Gdk::MOD1_MASK,
                                        Gtk::ACCEL_VISIBLE);
       m_increase_indent.signal_activate()
@@ -1228,7 +1238,7 @@ namespace gnote {
 
 //      m_decrease_indent.set_accel_group(accel_group);
       m_decrease_indent.add_accelerator ("activate", accel_group,
-                                         GDK_Left,
+                                         GDK_KEY_Left,
                                          Gdk::MOD1_MASK,
                                          Gtk::ACCEL_VISIBLE);
       m_decrease_indent.signal_activate()
